@@ -1,7 +1,7 @@
 package Sah::Schema::Rinci;
 
-our $DATE = '2015-02-07'; # DATE
-our $VERSION = '1.1.73'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '1.1.74'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,8 +33,7 @@ $SCHEMAS{rinci} = [hash => {
             _elem_prop => {
                 %dh_props,
 
-                uri => {},
-                title => {},
+                url => {},
             },
         },
     },
@@ -206,7 +205,7 @@ Sah::Schema::Rinci - Sah schemas for Rinci metadata
 
 =head1 VERSION
 
-This document describes version 1.1.73 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2015-02-07.
+This document describes version 1.1.74 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2015-03-18.
 
 =head1 HOMEPAGE
 
